@@ -773,34 +773,43 @@ failed:
 
 
 ExtFunc int
-open_stream_connection_unknown_encaps(args, port, timeout, p)
+open_stream_connection_unknown_encaps5(args, port, timeout, p, delta_t)
  struct arglist * args;
  unsigned int  port;
  int timeout, * p;
+ int	*delta_t;		/* time, in micro-seconds */
 {
  int fd;
  int i;
-#ifdef HAVE_SSL
+  struct timeval	tv1, tv2;
  static int encaps[] = {
+#ifdef HAVE_SSL
    NESSUS_ENCAPS_SSLv2,
    NESSUS_ENCAPS_TLSv1,
    NESSUS_ENCAPS_SSLv3,
-    };
 #endif
+    NESSUS_ENCAPS_IP
+  };
  
 #if DEBUG_SSL > 2
  fprintf(stderr, "[%d] open_stream_connection_unknown_encaps: TCP:%d; %d\n",
 	 getpid(), port,timeout);
 #endif
 
-#ifdef HAVE_SSL
  for (i = 0; i < sizeof(encaps) / sizeof(*encaps); i ++)
+    {
+      if (delta_t != NULL) (void) gettimeofday(&tv1, NULL);
    if ((fd = open_stream_connection(args, port, encaps[i], timeout)) >= 0)
      {
        *p = encaps[i];
 #if DEBUG_SSL > 2
        fprintf(stderr, "[%d] open_stream_connection_unknown_encaps: TCP:%d -> transport=%d\n", getpid(), port, *p);
 #endif
+	  if (delta_t != NULL)
+	    {
+	      (void) gettimeofday(&tv2, NULL);
+	      *delta_t = (tv2.tv_sec - tv1.tv_sec) * 1000000 + (tv2.tv_usec - tv1.tv_usec);
+	    }
        return fd;
      }
    else if (__port_closed)
@@ -810,23 +819,17 @@ open_stream_connection_unknown_encaps(args, port, timeout, p)
 #endif
        return -1;
      }
-
- /* 
-  * No need to try to connect to the remote port twice
-  */
- if(__port_closed)
+    }
   return -1;
-#endif 
- if ((fd = open_stream_connection(args, port, NESSUS_ENCAPS_IP, timeout)) >= 0)
- {
-  *p = NESSUS_ENCAPS_IP;
-#if DEBUG_SSL > 2
-       fprintf(stderr, "[%d] open_stream_connection_unknown_encaps: TCP:%d -> transport=%d\n", getpid(), port, *p);
-#endif
-  return fd;
  }
  
- return -1;
+ExtFunc int
+open_stream_connection_unknown_encaps(args, port, timeout, p)
+ struct arglist * args;
+ unsigned int  port;
+ int timeout, * p;
+{
+  return open_stream_connection_unknown_encaps5(args, port, timeout, p, NULL);
 }
 
 
@@ -1496,7 +1499,8 @@ open_socket(struct sockaddr_in *paddr,
   fd_set		fd_w;
   struct timeval	to;
   int			soc, x;
-  int			opt, opt_sz;
+  int			opt;
+  unsigned int opt_sz;
 
   __port_closed = 0;
 
