@@ -410,7 +410,7 @@ ExtFunc
 struct arglist * plug_get_required_keys(desc)
  struct arglist * desc;
 {
- return store_fetch_required_keys(desc);
+ return _plug_get_required_keys(desc);
 }
 
 
@@ -444,7 +444,7 @@ ExtFunc
 struct arglist * plug_get_excluded_keys(desc)
  struct arglist * desc;
 {
- return store_fetch_excluded_keys(desc);
+ return _plug_get_excluded_keys(desc);
 }
 
 ExtFunc 
@@ -478,7 +478,7 @@ ExtFunc
 struct arglist * plug_get_required_ports(desc)
  struct arglist * desc;
 {
- return store_fetch_required_ports(desc);
+ return _plug_get_required_ports(desc);
 }
 
 
@@ -513,7 +513,7 @@ ExtFunc
 struct arglist * plug_get_required_udp_ports(desc)
  struct arglist * desc;
 {
- return store_fetch_required_udp_ports(desc);
+ return _plug_get_required_udp_ports(desc);
 }
  
 
@@ -549,7 +549,10 @@ ExtFunc
 struct arglist * plug_get_deps(desc)
  struct arglist * desc;
 {
+ return _plug_get_deps(desc);
+#if 0
  return store_fetch_dependencies(desc);
+#endif
 }
 
 ExtFunc
@@ -573,7 +576,10 @@ ExtFunc
 int plug_get_timeout(desc)
  struct arglist * desc;
 {
+ return _plug_get_timeout(desc);
+#if 0
  return store_fetch_timeout(desc);
+#endif
 }
 
 		
@@ -636,7 +642,8 @@ ExtFunc
 char * plug_get_name(desc)
  struct arglist * desc;
 {
- return store_fetch_name(desc);
+ return _plug_get_name(desc);
+ /*return store_fetch_name(desc);*/
 }
 
 
@@ -1406,14 +1413,14 @@ void * plug_get_fresh_key(args, name, type)
  e = internal_send(soc, name, INTERNAL_COMM_MSG_TYPE_KB|INTERNAL_COMM_KB_GET);
  if(e < 0){
         fprintf(stderr, "[%d] plug_get_fresh_key:internal_send(%d): %s\n",getpid(), soc,name, strerror(errno));
-	return NULL;
+	goto err;
 	}
 
  internal_recv(soc, &buf, &bufsz, &msg); 
  if ( ( msg & INTERNAL_COMM_MSG_TYPE_KB ) == 0  )
  {
         fprintf(stderr, "[%d] plug_get_fresh_key:internal_send(%d): Unexpected message %d",getpid(), soc, msg);
-	return NULL;
+	goto err;
  }
 
  if ( msg & INTERNAL_COMM_KB_ERROR ) return NULL;
@@ -1421,14 +1428,20 @@ void * plug_get_fresh_key(args, name, type)
  {
   char * ret = estrdup(buf);
   *type = ARG_STRING;
+  efree(&buf);
   return ret;
  } 
  else if ( msg & INTERNAL_COMM_KB_SENDING_INT )
  {
+  int ret;
   *type = ARG_INT;
-  return (void*)atoi(buf);
+  ret = atoi(buf);
+  efree(&buf);
+  return (void*)ret;
  }
- else return NULL; 
+err:
+ if ( buf != NULL )efree(&buf);
+ return NULL; 
 } 
 
 static void plug_set_replace_key(args, name, type, value, replace)
@@ -2002,7 +2015,8 @@ is_shell_command_present(name)
 ExtFunc int shared_socket_register ( struct arglist * args, int fd, char * name )
 {
  int soc; 
- int type, opt_len = sizeof(type);
+ int type;
+ unsigned int opt_len = sizeof(type);
  int e;  
  soc = (int)arg_get_value(args, "SOCKET");
  if ( fd_is_stream(fd) )
@@ -2025,8 +2039,8 @@ ExtFunc int shared_socket_register ( struct arglist * args, int fd, char * name
 ExtFunc int shared_socket_acquire ( struct arglist * args, char * name )
 {
  int soc; 
- char * buf;
- int bufsz;
+ char * buf = NULL;
+ int bufsz = 0;
  int msg;
 
  soc = (int)arg_get_value(args, "SOCKET");
@@ -2034,8 +2048,8 @@ ExtFunc int shared_socket_acquire ( struct arglist * args, char * name )
  /* Wait forever until SHARED_SOCKET_ACQUIRE is true */
  for ( ;; )
  {
- internal_send(soc, name, INTERNAL_COMM_MSG_SHARED_SOCKET|INTERNAL_COMM_SHARED_SOCKET_ACQUIRE);
- internal_recv(soc, &buf, &bufsz, &msg);
+ if ( internal_send(soc, name, INTERNAL_COMM_MSG_SHARED_SOCKET|INTERNAL_COMM_SHARED_SOCKET_ACQUIRE) < 0 ) break;
+ if ( internal_recv(soc, &buf, &bufsz, &msg) < 0 ) break;
  if ( ( msg & INTERNAL_COMM_MSG_SHARED_SOCKET) == 0 )
 	{
 	 fprintf(stderr, "[%d] shared_socket_acquire(): unexpected message - %d\n", getpid(), msg);
