@@ -168,6 +168,7 @@ int store_get_plugin_f(struct plugin * plugin, struct pprefs * pprefs, char * di
  char file_name[PATH_MAX+1];
  char * str;
  
+ bzero(plugin, sizeof(*plugin));
  plugin->id = -1;
  
  if(dir == NULL || dir[0] == '\0' || file == NULL || file[0] == '\0')
@@ -248,6 +249,7 @@ struct arglist * store_load_plugin(char * dir, char * file,  struct arglist * pr
  struct arglist * ret;
  int i;
  struct stat st1, st2;
+ struct arglist * al;
  
  bzero(pp, sizeof(pp));
  
@@ -284,6 +286,30 @@ struct arglist * store_load_plugin(char * dir, char * file,  struct arglist * pr
  plug_set_category(ret, p.category);
  plug_set_fname(ret, file);
  plug_set_path(ret, p.path);
+ plug_set_family(ret, p.family, NULL);
+
+  al = str2arglist(p.required_ports);
+ if ( al != NULL ) arg_add_value(ret, "required_ports", ARG_ARGLIST, -1, al);
+
+ al = str2arglist(p.required_keys);
+ if ( al != NULL ) arg_add_value(ret, "required_keys", ARG_ARGLIST, -1, al);
+
+ al = str2arglist(p.required_udp_ports);
+ if ( al != NULL ) arg_add_value(ret, "required_udp_ports", ARG_ARGLIST, -1, al)
+;
+
+ al = str2arglist(p.excluded_keys);
+ if ( al != NULL ) arg_add_value(ret, "excluded_keys", ARG_ARGLIST, -1, al);
+
+ al = str2arglist(p.dependencies);
+ if ( al != NULL ) arg_add_value(ret, "DEPENDENCIES", ARG_ARGLIST, -1, al);
+
+ 
+ if ( p.timeout != 0 ) arg_add_value(ret, "TIMEOUT", ARG_INT, -1, (void*)p.timeout);
+
+ arg_add_value(ret, "NAME", ARG_STRING, strlen(p.name), estrdup(p.name));
+
+
  arg_add_value(ret, "preferences", ARG_ARGLIST, -1, prefs);
  
  if(p.has_prefs)
@@ -498,15 +524,10 @@ struct arglist * store_plugin(struct arglist * plugin, char * file)
  close(fd); 
  
  
- ret = emalloc(sizeof(struct arglist));
- plug_set_id(ret, _plug_get_id(plugin));
- plug_set_category(ret, _plug_get_category(plugin));
- plug_set_fname(ret, file);
- plug_set_path(ret, path);
- arg_add_value(ret, "preferences", ARG_ARGLIST, -1, arg_get_value(plugin, "preferences"));
+
  arg_set_value(plugin, "preferences", -1, NULL);
  arg_free_all(plugin);
- return ret;
+ return NULL;
 }
 
 
